# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.0.4](https://github.com/k88hudson/plzplz/compare/v0.0.3...v0.0.4) - 2026-02-19

### Added

- Added support for git hooks
- Publishing via pypi
- Some additional hints


### Fixed

- Issue with environments not being added to failure hooks
